@@ -26,9 +26,10 @@ Assumptions::~Assumptions() {}
 
 bool Assumptions::isPositive() {return i_sign == ASSUMPTION_SIGN_POSITIVE || (fmin && (fmin->isPositive() || (!b_incl_min && fmin->isNonNegative())));}
 bool Assumptions::isNegative() {return i_sign == ASSUMPTION_SIGN_NEGATIVE || (fmax && (fmax->isNegative() || (!b_incl_max && fmax->isNonPositive())));}
-bool Assumptions::isNonNegative() {return i_sign == ASSUMPTION_SIGN_NONNEGATIVE || i_sign == ASSUMPTION_SIGN_POSITIVE || (fmin && fmin->isNonNegative());}
+bool Assumptions::isNonNegative() {return i_type == ASSUMPTION_TYPE_BOOLEAN || i_sign == ASSUMPTION_SIGN_NONNEGATIVE || i_sign == ASSUMPTION_SIGN_POSITIVE || (fmin && fmin->isNonNegative());}
 bool Assumptions::isNonPositive() {return i_sign == ASSUMPTION_SIGN_NONPOSITIVE || i_sign == ASSUMPTION_SIGN_NEGATIVE || (fmax && fmax->isNonPositive());}
 bool Assumptions::isInteger() {return i_type >= ASSUMPTION_TYPE_INTEGER;}
+bool Assumptions::isBoolean() {return i_type == ASSUMPTION_TYPE_BOOLEAN || (i_type == ASSUMPTION_TYPE_INTEGER && fmin && fmax && fmin->isZero() && fmax->isOne());}
 bool Assumptions::isNumber() {return i_type >= ASSUMPTION_TYPE_NUMBER || fmin || fmax;}
 bool Assumptions::isRational() {return i_type >= ASSUMPTION_TYPE_RATIONAL;}
 bool Assumptions::isReal() {return i_type >= ASSUMPTION_TYPE_REAL || (fmin && !fmin->hasImaginaryPart()) || (fmax && !fmax->hasImaginaryPart());}
@@ -41,17 +42,17 @@ AssumptionType Assumptions::type() {return i_type;}
 AssumptionSign Assumptions::sign() {return i_sign;}
 void Assumptions::setType(AssumptionType ant) {
 	i_type = ant;
-	if(i_type <= ASSUMPTION_TYPE_COMPLEX && i_sign != ASSUMPTION_SIGN_NONZERO) {
+	if(i_type == ASSUMPTION_TYPE_BOOLEAN || (i_type <= ASSUMPTION_TYPE_COMPLEX && i_sign != ASSUMPTION_SIGN_NONZERO)) {
 		i_sign = ASSUMPTION_SIGN_UNKNOWN;
 	}
-	if(i_type <= ASSUMPTION_TYPE_NONMATRIX) {
+	if(i_type <= ASSUMPTION_TYPE_NONMATRIX || i_type == ASSUMPTION_TYPE_BOOLEAN) {
 		if(fmax) delete fmax;
 		if(fmin) delete fmin;
 	}
 }
 void Assumptions::setSign(AssumptionSign as) {
 	i_sign = as;
-	if(i_type <= ASSUMPTION_TYPE_COMPLEX && i_sign != ASSUMPTION_SIGN_NONZERO && i_sign != ASSUMPTION_SIGN_UNKNOWN) {
+	if((i_type == ASSUMPTION_TYPE_BOOLEAN && i_sign != ASSUMPTION_SIGN_UNKNOWN) || (i_type <= ASSUMPTION_TYPE_COMPLEX && i_sign != ASSUMPTION_SIGN_NONZERO && i_sign != ASSUMPTION_SIGN_UNKNOWN)) {
 		i_type = ASSUMPTION_TYPE_REAL;
 	}
 }
@@ -63,7 +64,7 @@ void Assumptions::setMin(const Number *nmin) {
 		}
 		return;
 	}
-	if(i_type <= ASSUMPTION_TYPE_NONMATRIX) i_type = ASSUMPTION_TYPE_NUMBER;
+	if(i_type <= ASSUMPTION_TYPE_COMPLEX || i_type == ASSUMPTION_TYPE_BOOLEAN) i_type = ASSUMPTION_TYPE_REAL;
 	if(!fmin) {
 		fmin = new Number(*nmin);
 	} else {
@@ -86,7 +87,7 @@ void Assumptions::setMax(const Number *nmax) {
 		}
 		return;
 	}
-	if(i_type <= ASSUMPTION_TYPE_NONMATRIX) i_type = ASSUMPTION_TYPE_NUMBER;
+	if(i_type <= ASSUMPTION_TYPE_COMPLEX || i_type == ASSUMPTION_TYPE_BOOLEAN) i_type = ASSUMPTION_TYPE_REAL;
 	if(!fmax) {
 		fmax = new Number(*nmax);
 	} else {
@@ -244,6 +245,11 @@ bool UnknownVariable::representsNonZero(bool b) {
 	if(o_assumption) return o_assumption->isNonZero();
 	return CALCULATOR->defaultAssumptions()->isNonZero();
 }
+bool UnknownVariable::representsBoolean() {
+	if(mstruct) return mstruct->representsBoolean();
+	if(o_assumption) return o_assumption->isBoolean();
+	return CALCULATOR->defaultAssumptions()->isBoolean();
+}
 bool UnknownVariable::representsNonMatrix() {
 	if(o_assumption) return o_assumption->isNonMatrix();
 	return CALCULATOR->defaultAssumptions()->isNonMatrix();
